Color

Struct Color 

pub struct Color { /* private fields */ }
A struct representing a color with red, green, blue, and alpha components. Each component is stored as a float.

Implementations

Source

impl Color

pub const TRANSPARENT: Color

Color constant for transparency, with the alpha value set to zero.

pub const BLACK: Color

Constant for the color black.

pub const WHITE: Color

Constant for the color white.

pub const RED: Color

Constant for the color red.

pub const GREEN: Color

Constant for the color green.

pub const BLUE: Color

Constant for the color blue.

pub const YELLOW: Color

Constant for the color yellow.

pub const CYAN: Color

Constant for the color cyan.

pub const MAGENTA: Color

Constant for the color magenta.

pub const GRAY: Color

Constant for the color gray.

pub const LIGHT_GRAY: Color

Constant for the color light gray.

pub const DARK_GRAY: Color

Constant for the color dark gray.

pub const fn from_rgba(r: f32, g: f32, b: f32, a: f32) -> Self

Creates a color with the specified components, including an alpha component. Each component should be in the range 0.0 to 1.0.

pub const fn from_rgb(r: f32, g: f32, b: f32) -> Self

Creates a color with the specified components. The alpha component will be set to 1.0 (full opacity). Each component should be in the range 0.0 to 1.0.

pub fn from_int_rgba(r: u8, g: u8, b: u8, a: u8) -> Self

Creates a color with the specified components, including an alpha component. Each component should be in the range 0 to 255.

pub fn from_int_rgb(r: u8, g: u8, b: u8) -> Self

Creates a color with the specified components. The alpha component will be set to 255 (full opacity). Each component should be in the range 0 to 255.

pub fn from_hex_argb(argb: u32) -> Self

Creates a color from the specified integer value, including an alpha component.

For example, the input value 0xAABBCCDD will result in a color with:

  • Alpha = 0xAA
  • Red = 0xBB
  • Green = 0xCC
  • Blue = 0xDD

Note: If you don’t specify the alpha component, the color will be transparent.

pub fn from_hex_rgb(rgb: u32) -> Self

Creates a color from the specified integer value, with the alpha component set to 255 (full opacity).

For example, the input value 0xAABBCC will result in a color with:

  • Alpha = 0xFF
  • Red = 0xAA
  • Green = 0xBB
  • Blue = 0xCC

Note: if an alpha component is specified in the high bits of the integer, it will be ignored. See Color::from_hex_argb if you wish to specify the alpha component.

pub const fn from_gray(brightness: f32) -> Self

Creates a shade of gray from the specified float value, between 0.0 and 1.0. All three RGB components will be set to this value.

pub const fn r(&self) -> f32

Returns the red component of the color, as a value in the range 0.0 to 1.0.

pub const fn g(&self) -> f32

Returns the green component of the color, as a value in the range 0.0 to 1.0.

pub const fn b(&self) -> f32

Returns the blue component of the color, as a value in the range 0.0 to 1.0.

pub const fn a(&self) -> f32

Returns the alpha component of the color, as a value in the range 0.0 to 1.0. The value 0.0 is fully transparent, and the value 1.0 is fully opaque.

pub fn subjective_brightness(&self) -> f32

Returns the brightness of the color as perceived by a human, as a value in the range 0.0 to 1.0.

This is calculated using the following formula:

red * 0.299 + green * 0.587 + blue * 0.114