pub struct Codepoint { /* private fields */ }Expand description
A struct representing a Unicode codepoint, for the purposes of text layout.
The user_index field allows you to determine which output glyph
corresponds to which input codepoint.
Implementations
Sourceimpl Codepoint
impl Codepoint
Sourcepub const ZERO_WIDTH_SPACE: char = '\u{200B}'
pub const ZERO_WIDTH_SPACE: char = '\u{200B}'
The Unicode codepoint for a zero width space. You may use this to denote places where it would be appropriate to insert a line break when wrapping.
Sourcepub fn new(user_index: UserGlyphIndex, codepoint: char) -> Self
pub fn new(user_index: UserGlyphIndex, codepoint: char) -> Self
Instantiates a new Codepoint. The value provided for user_index will
be present in the corresponding FormattedGlyph object returned
during layout.