pub struct FormattedTextBlock { /* private fields */ }Expand description
Represents a block of text which has been laid out.
Implementations
Sourceimpl FormattedTextBlock
impl FormattedTextBlock
Sourcepub fn iter_lines(&self) -> Iter<'_, FormattedTextLine>
pub fn iter_lines(&self) -> Iter<'_, FormattedTextLine>
Iterate over the lines of text in this block.