pub struct FormattedTextLine { /* private fields */ }Expand description
Represents a line of text which has been laid out as part of a block.
Implementations
Sourceimpl FormattedTextLine
impl FormattedTextLine
Sourcepub fn iter_glyphs(&self) -> Iter<'_, FormattedGlyph>
pub fn iter_glyphs(&self) -> Iter<'_, FormattedGlyph>
Iterate over the glyphs in this line.
Sourcepub fn as_block(&self) -> FormattedTextBlock
pub fn as_block(&self) -> FormattedTextBlock
Convert this line of text into an individually-renderable block (while maintaining the same vertical offset).
Sourcepub fn height(&self) -> f32
pub fn height(&self) -> f32
The height (in pixels) of this text line. This is equal to the
ascent() minus the descent().
Sourcepub fn ascent(&self) -> f32
pub fn ascent(&self) -> f32
The ascent (in pixels) of this text line. This is the maximum height of each glyph above the text baseline.
Sourcepub fn descent(&self) -> f32
pub fn descent(&self) -> f32
The descent (in pixels) of this text line. This is the furthest distance of each glyph below the text baseline.
This is negative: a value of -10.0 means the font can descend 10
pixels below the baseline.
Sourcepub fn line_gap(&self) -> f32
pub fn line_gap(&self) -> f32
The recommended gap to put between each line of text, as encoded by the font authors.
Sourcepub fn baseline_position(&self) -> f32
pub fn baseline_position(&self) -> f32
The vertical position of this line’s baseline within the block of text.