TextOptions

Struct TextOptions 

pub struct TextOptions { /* private fields */ }
A series of options for specifying how text should be laid out.

Implementations

Source

impl TextOptions

pub fn new() -> Self

Instantiates a new TextOptions with the default settings.

pub fn with_tracking(self, tracking: f32) -> Self

Sets the tracking of the font. This is the amount of extra space (in pixels) to put between each character.

The default is 0.0.

pub fn with_wrap_to_width( self, wrap_words_after_width_px: f32, alignment: TextAlignment, ) -> Self

Limits the width of the text block to the specified pixel value, wrapping words to a new line if they exceed that limit.

This function also sets the alignment, within the specified width.

The default is to not wrap text.

pub fn with_line_spacing_multiplier(self, line_spacing_multiplier: f32) -> Self

Sets the amount of space between each line of text. The gap between the baseline of each line of text is multiplied by this value.

The default is 1.0.

pub fn with_trim_each_line(self, trim_each_line: bool) -> Self

True if whitespace should be trimmed at the beginning of each line, false to preserve whitespace.

The default is true.