pub enum ImageDataType {
RGB,
RGBA,
}Expand description
The data type of the pixels making up the raw image data.
Variants
RGB
Each pixel in the image is represented by three u8 values: red, green,
and blue.
RGBA
Each pixel in the image is represented by four u8 values: red, green,
blue, and alpha.