Module numeric

Module numeric 

Utilities and traits for numeric values.

Traits

PrimitiveZero
A trait defined for primitives which have a zero value.
RoundFloat
Types implementing this trait can be rounded to the nearest integer value. In the case of vectors or other types containing multiple elements, each element will be individually rounded.