pub struct Rectangle<T = f32> { /* private fields */ }Expand description
A struct representing an axis-aligned rectangle. Two points are stored: the top left vertex, and the bottom right vertex.
Implementations
Sourceimpl<T> Rectangle<T>
impl<T> Rectangle<T>
Sourcepub const fn new(top_left: Vector2<T>, bottom_right: Vector2<T>) -> Self
pub const fn new(top_left: Vector2<T>, bottom_right: Vector2<T>) -> Self
Constructs a new Rectangle. The top left vertex must be above and to
the left of the bottom right vertex.
Sourcepub fn from_tuples(top_left: (T, T), bottom_right: (T, T)) -> Self
pub fn from_tuples(top_left: (T, T), bottom_right: (T, T)) -> Self
Constructs a new Rectangle. The top left vertex must be above and to
the left of the bottom right vertex.
Sourcepub const fn bottom_right(&self) -> &Vector2<T>
pub const fn bottom_right(&self) -> &Vector2<T>
Returns a reference to the bottom right vertex.
Sourceimpl<T: Copy> Rectangle<T>
impl<T: Copy> Rectangle<T>
Sourcepub fn rounded(&self, radius: T) -> RoundedRectangle<T>
pub fn rounded(&self, radius: T) -> RoundedRectangle<T>
Returns a new RoundedRectangle which has the same sizes of Self and
a radius of T
Sourcepub fn bottom_left(&self) -> Vector2<T>
pub fn bottom_left(&self) -> Vector2<T>
Returns a vector representing the bottom left vertex.
Sourceimpl<T: PartialOrd<T> + Copy> Rectangle<T>
impl<T: PartialOrd<T> + Copy> Rectangle<T>
Sourceimpl<T: PartialOrd + Copy> Rectangle<T>
impl<T: PartialOrd + Copy> Rectangle<T>
Sourceimpl<T: PrimitiveZero> Rectangle<T>
impl<T: PrimitiveZero> Rectangle<T>
Sourceimpl<T: PartialEq> Rectangle<T>
impl<T: PartialEq> Rectangle<T>
Sourcepub fn is_zero_area(&self) -> bool
pub fn is_zero_area(&self) -> bool
Returns true if the rectangle has zero area.
Sourceimpl<T: PartialOrd> Rectangle<T>
impl<T: PartialOrd> Rectangle<T>
Sourcepub fn is_positive_area(&self) -> bool
pub fn is_positive_area(&self) -> bool
Returns true if the rectangle has an area greater than zero.
Sourceimpl<T: Copy> Rectangle<T>
impl<T: Copy> Rectangle<T>
Sourcepub fn with_offset(&self, offset: impl Into<Vector2<T>>) -> Self
pub fn with_offset(&self, offset: impl Into<Vector2<T>>) -> Self
Returns a new rectangle, whose vertices are offset relative to the current rectangle by the specified amount. This is equivalent to adding the specified vector to each vertex.
Sourceimpl<T: Copy> Rectangle<T>
impl<T: Copy> Rectangle<T>
Sourcepub fn with_negative_offset(&self, offset: impl Into<Vector2<T>>) -> Self
pub fn with_negative_offset(&self, offset: impl Into<Vector2<T>>) -> Self
Returns a new rectangle, whose vertices are negatively offset relative to the current rectangle by the specified amount. This is equivalent to subtracting the specified vector to each vertex.
Sourceimpl<T: AsPrimitive<f32>> Rectangle<T>
impl<T: AsPrimitive<f32>> Rectangle<T>