RoundedRectangle

Struct RoundedRectangle 

pub struct RoundedRectangle<T = f32> { /* private fields */ }
A struct representing an axis-aligned rounded rectangle. Two points and a value of type ‘T’ are stored: the top left vertex, the bottom right vertex and the radius of the rounded corners.

Implementations

Source

impl<T: Copy + Neg<Output = T> + Add<Output = T>> RoundedRectangle<T>

pub fn inner(&self) -> Rectangle<T>

returns a Rectangle representing the inner rectangle of this rounded rectangle.

Source

impl<T> RoundedRectangle<T>

pub const fn new( top_left: Vector2<T>, bottom_right: Vector2<T>, radius: T, ) -> Self

Constructs a new RoundedRectangle. The top left vertex must be above and to the left of the bottom right vertex. A negative radius won’t be checked. A big radius (larger than half the width or height) might produce unexpected behavior but it won’t be checked.

pub fn from_tuples(top_left: (T, T), bottom_right: (T, T), radius: T) -> Self

Constructs a new RoundedRectangle. The top left vertex must be above and to the left of the bottom right vertex. A negative radius won’t be checked. A big radius (larger than half the width or height) might produce unexpected behavior but it won’t be checked.

Note: a negative radius won’t be checked at runtime.

pub fn from_rectangle(rect: Rectangle<T>, radius: T) -> Self

Constructs a new RoundedRectangle from a Rectangle and a radius. A negative radius won’t be checked. A big radius (larger than half the width or height) might produce unexpected behavior but it won’t be checked.

pub const fn top_left(&self) -> &Vector2<T>

Returns a reference to the top left vertex.

pub const fn bottom_right(&self) -> &Vector2<T>

Returns a reference to the bottom right vertex.

Source

impl<T: Copy> RoundedRectangle<T>

pub fn top_right(&self) -> Vector2<T>

Returns a vector representing the top right vertex.

pub fn bottom_left(&self) -> Vector2<T>

Returns a vector representing the bottom left vertex.

pub fn radius(&self) -> T

Returns the radius of the rounded corners.

pub fn left(&self) -> T

Returns the x value of the left border

pub fn right(&self) -> T

Returns the x value of the right border

pub fn top(&self) -> T

Returns the y value of the top border

pub fn bottom(&self) -> T

Returns the y value of the bottom border

pub fn as_rectangle(&self) -> &Rectangle<T>

Returns a Rectangle representing the rectangle that encloses this rounded rectangle.

Source

impl<T: Sub<Output = T> + Copy> RoundedRectangle<T>

pub fn width(&self) -> T

Returns the width of the rounded rectangle.

pub fn height(&self) -> T

Returns the height of the rounded rectangle.

pub fn size(&self) -> Vector2<T>

Returns a Vector2 containing the width and height of the rounded rectangle.

Source

impl<T> RoundedRectangle<T>
where T: AsPrimitive<f32> + PartialOrd + Add<Output = T> + Sub<Output = T> + Mul<Output = T> + Neg<Output = T> + Div<Output = f32> + Div<f32, Output = T> + Zero,

pub fn contains(&self, point: Vector2<T>) -> bool

Returns true if the specified point is inside this rounded rectangle. Note: this is always inclusive, in contrast to the contains method of Rect which is sometimes exclusive.

Source

impl<T: PartialEq> RoundedRectangle<T>

pub fn is_zero_area(&self) -> bool

Returns true if the rectangle containing this rounded rectangle has zero area. (the radius is not taken into account)

Source

impl<T: PartialOrd> RoundedRectangle<T>

pub fn is_positive_area(&self) -> bool

Returns true if the rectangle containing this rounded rectangle has positive area. (the radius is not taken into account)

Source

impl<T: Copy> RoundedRectangle<T>
where Vector2<T>: Add<Output = Vector2<T>>,

pub fn with_offset(&self, offset: impl Into<Vector2<T>>) -> Self

Returns a new rounded rectangle, whose vertices are offset relative to the current rounded rectangle by the specified amount. This is equivalent to adding the specified vector to each vertex.

Source

impl<T: Copy> RoundedRectangle<T>
where Vector2<T>: Sub<Output = Vector2<T>>,

pub fn with_negative_offset(&self, offset: impl Into<Vector2<T>>) -> Self

Returns a new rounded rectangle, whose vertices are negatively offset relative to the current rectangle by the specified amount. This is equivalent to subtracting the specified vector to each vertex.

Source

impl<T: AsPrimitive<f32>> RoundedRectangle<T>

pub fn into_f32(self) -> RoundedRectangle<f32>

Returns a new rounded rectangle where the coordinates and the radius have been cast to f32 values, using the as operator.

Source

impl<T: AsPrimitive<f32> + Copy> RoundedRectangle<T>

pub fn as_f32(&self) -> RoundedRectangle<f32>

Returns a new rectangle where the coordinates have been cast to f32 values, using the as operator.