MouseCursorType

Enum MouseCursorType 

#[non_exhaustive]
pub enum MouseCursorType {
Show 23 variants Default, Pointer, Crosshair, Text, VerticalText, Move, Grab, Grabbing, Wait, Progress, Cell, Alias, Copy, NoDrop, NotAllowed, ColResize, RowResize, EwResize, NsResize, NeswResize, NwseResize, ZoomIn, ZoomOut,
}
Identifies the shape of the mouse cursor displayed over the window. See WindowHelper::set_cursor.

The variants mirror the standard CSS cursor keywords and map directly onto the native cursors provided by each platform backend.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Default

The platform-dependent default cursor (usually an arrow).



Pointer

A pointing hand, typically used to indicate a link.



Crosshair

A crosshair.



Text

Indicates editable text (usually an I-beam).



VerticalText

Indicates editable vertical text.



Move

Indicates that something can be moved.



Grab

Indicates that something can be grabbed (an open hand).



Grabbing

Indicates that something is being grabbed (a closed hand).



Wait

Indicates that the program is busy and the user should wait.



Progress

Indicates that the program is busy in the background, but the user can still interact with the interface.



Cell

Indicates that a cell or set of cells may be selected.



Alias

Indicates an alias of/shortcut to something is to be created.



Copy

Indicates something is to be copied.



NoDrop

Indicates that the dragged item cannot be dropped at the current location.



NotAllowed

Indicates that the requested action will not be carried out.



ColResize

Indicates that an edge of a box is to be moved left/right.



RowResize

Indicates that an edge of a box is to be moved up/down.



EwResize

Indicates a horizontal (east-west) resize.



NsResize

Indicates a vertical (north-south) resize.



NeswResize

Indicates a bidirectional north-east/south-west resize.



NwseResize

Indicates a bidirectional north-west/south-east resize.



ZoomIn

Indicates that something can be zoomed in.



ZoomOut

Indicates that something can be zoomed out.