pub enum MouseScrollDistance {
Lines {
x: f64,
y: f64,
z: f64,
},
Pixels {
x: f64,
y: f64,
z: f64,
},
Pages {
x: f64,
y: f64,
z: f64,
},
}Expand description
Describes a difference in the mouse scroll wheel position.
Variants
Lines
Number of lines or rows to scroll in each direction. The y field
represents the vertical scroll direction on a typical mouse wheel.
Fields
x: f64The horizontal scroll distance. Negative values indicate scrolling left, and positive values indicate scrolling right.
Pixels
Number of pixels to scroll in each direction. Scroll events are
expressed in pixels if supported by the device (eg. a touchpad) and
platform. The y field represents the vertical scroll direction on a
typical mouse wheel.
Fields
x: f64The horizontal scroll distance. Negative values indicate scrolling left, and positive values indicate scrolling right.
Pages
Number of pages to scroll in each direction (only supported for
WebCanvas). The y field represents the vertical scroll direction on a
typical mouse wheel.