#[non_exhaustive]pub enum WindowCreationError {
PrimaryMonitorNotFound,
SuitableContextNotFound,
MakeContextCurrentFailed,
RendererCreationFailed,
EventLoopCreationFailed,
}Expand description
Error occurring when creating a window.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
PrimaryMonitorNotFound
Could not find the primary monitor.
SuitableContextNotFound
Could not find a suitable graphics context. Speedy2D attempts to find the best possible context configuration by trying multiple options for vsync and multisampling.
MakeContextCurrentFailed
Failed to make the graphics context current.
RendererCreationFailed
Failed to instantiate the renderer.
EventLoopCreationFailed
Failed to instantiate the main window event loop.