pub enum WindowSize {
PhysicalPixels(UVec2),
ScaledPixels(Vec2),
MarginPhysicalPixels(u32),
MarginScaledPixels(f32),
}Expand description
The size of the window to create.
Variants
PhysicalPixels(UVec2)
Define the window size in pixels.
ScaledPixels(Vec2)
Define the window size in device-independent scaled pixels.
MarginPhysicalPixels(u32)
Make the window fill the screen, except for a margin around the outer edges.
MarginScaledPixels(f32)
Make the window fill the screen, except for a margin around the outer edges.