Utilities and traits for numeric values.
Traits
- Primitive
Zero - A trait defined for primitives which have a zero value.
- Round
Float - Types implementing this trait can be rounded to the nearest integer value. In the case of vectors or other types containing multiple elements, each element will be individually rounded.