pub trait RoundFloat {
// Required method
fn round(&self) -> Self;
}Expand description
Types implementing this trait can be rounded to the nearest integer value. In the case of vectors or other types containing multiple elements, each element will be individually rounded.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".