Rectangle

Struct Rectangle 

pub struct Rectangle<T = f32> { /* private fields */ }
A struct representing an axis-aligned rectangle. Two points are stored: the top left vertex, and the bottom right vertex.

Implementations

Source

impl<T> Rectangle<T>

pub const fn new(top_left: Vector2<T>, bottom_right: Vector2<T>) -> Self

Constructs a new Rectangle. The top left vertex must be above and to the left of the bottom right vertex.

pub fn from_tuples(top_left: (T, T), bottom_right: (T, T)) -> Self

Constructs a new Rectangle. The top left vertex must be above and to the left of the bottom right vertex.

pub const fn top_left(&self) -> &Vector2<T>

Returns a reference to the top left vertex.

pub const fn bottom_right(&self) -> &Vector2<T>

Returns a reference to the bottom right vertex.

Source

impl<T: Copy> Rectangle<T>

pub fn rounded(&self, radius: T) -> RoundedRectangle<T>

Returns a new RoundedRectangle which has the same sizes of Self and a radius of T

pub fn top_right(&self) -> Vector2<T>

Returns a vector representing the top right vertex.

pub fn bottom_left(&self) -> Vector2<T>

Returns a vector representing the bottom left vertex.

pub fn left(&self) -> T

Returns the x value of the left border

pub fn right(&self) -> T

Returns the x value of the right border

pub fn top(&self) -> T

Returns the y value of the top border

pub fn bottom(&self) -> T

Returns the y value of the bottom border

Source

impl<T: Sub<Output = T> + Copy> Rectangle<T>

pub fn width(&self) -> T

Returns the width of the rectangle.

pub fn height(&self) -> T

Returns the height of the rectangle.

pub fn size(&self) -> Vector2<T>

Returns a Vector2 containing the width and height of the rectangle.

Source

impl<T: PartialOrd<T> + Copy> Rectangle<T>

pub fn contains(&self, point: Vector2<T>) -> bool

Returns true if the specified point is inside this rectangle. This is inclusive of the top and left coordinates, and exclusive of the bottom and right coordinates.

Source

impl<T: PartialOrd + Copy> Rectangle<T>

pub fn intersect(&self, other: &Self) -> Option<Self>

Finds the intersection of two rectangles – in other words, the area that is common to both of them.

If there is no common area between the two rectangles, then this function will return None.

Source

impl<T: PrimitiveZero> Rectangle<T>

pub const ZERO: Rectangle<T>

A constant representing a rectangle with position (0, 0) and zero area. Each component is set to zero.

Source

impl<T: PartialEq> Rectangle<T>

pub fn is_zero_area(&self) -> bool

Returns true if the rectangle has zero area.

Source

impl<T: PartialOrd> Rectangle<T>

pub fn is_positive_area(&self) -> bool

Returns true if the rectangle has an area greater than zero.

Source

impl<T: Copy> Rectangle<T>
where Vector2<T>: Add<Output = Vector2<T>>,

pub fn with_offset(&self, offset: impl Into<Vector2<T>>) -> Self

Returns a new rectangle, whose vertices are offset relative to the current rectangle by the specified amount. This is equivalent to adding the specified vector to each vertex.

Source

impl<T: Copy> Rectangle<T>
where Vector2<T>: Sub<Output = Vector2<T>>,

pub fn with_negative_offset(&self, offset: impl Into<Vector2<T>>) -> Self

Returns a new rectangle, whose vertices are negatively offset relative to the current rectangle by the specified amount. This is equivalent to subtracting the specified vector to each vertex.

Source

impl<T: AsPrimitive<f32>> Rectangle<T>

pub fn into_f32(self) -> Rectangle<f32>

Returns a new rectangle where the coordinates have been cast to f32 values, using the as operator.

Source

impl<T: AsPrimitive<f32> + Copy> Rectangle<T>

pub fn as_f32(&self) -> Rectangle<f32>

Returns a new rectangle where the coordinates have been cast to f32 values, using the as operator.