pub struct RoundedRectangle<T = f32> { /* private fields */ }Expand description
A struct representing an axis-aligned rounded rectangle. Two points and a value of type ‘T’ are stored: the top left vertex, the bottom right vertex and the radius of the rounded corners.
Implementations
Sourceimpl<T> RoundedRectangle<T>
impl<T> RoundedRectangle<T>
Sourcepub const fn new(
top_left: Vector2<T>,
bottom_right: Vector2<T>,
radius: T,
) -> Self
pub const fn new( top_left: Vector2<T>, bottom_right: Vector2<T>, radius: T, ) -> Self
Constructs a new RoundedRectangle. The top left vertex must be above
and to the left of the bottom right vertex. A negative radius won’t be
checked. A big radius (larger than half the width or height)
might produce unexpected behavior but it won’t be checked.
Sourcepub fn from_tuples(top_left: (T, T), bottom_right: (T, T), radius: T) -> Self
pub fn from_tuples(top_left: (T, T), bottom_right: (T, T), radius: T) -> Self
Constructs a new RoundedRectangle. The top left vertex must be above
and to the left of the bottom right vertex. A negative radius won’t be
checked. A big radius (larger than half the width or height)
might produce unexpected behavior but it won’t be checked.
Note: a negative radius won’t be checked at runtime.
Sourcepub fn from_rectangle(rect: Rectangle<T>, radius: T) -> Self
pub fn from_rectangle(rect: Rectangle<T>, radius: T) -> Self
Constructs a new RoundedRectangle from a Rectangle and a radius.
A negative radius won’t be checked.
A big radius (larger than half the width or height) might produce
unexpected behavior but it won’t be checked.
Sourcepub const fn bottom_right(&self) -> &Vector2<T>
pub const fn bottom_right(&self) -> &Vector2<T>
Returns a reference to the bottom right vertex.
Sourceimpl<T: Copy> RoundedRectangle<T>
impl<T: Copy> RoundedRectangle<T>
Sourcepub fn bottom_left(&self) -> Vector2<T>
pub fn bottom_left(&self) -> Vector2<T>
Returns a vector representing the bottom left vertex.
Sourcepub fn as_rectangle(&self) -> &Rectangle<T>
pub fn as_rectangle(&self) -> &Rectangle<T>
Returns a Rectangle representing the rectangle that encloses this
rounded rectangle.
Sourceimpl<T: Sub<Output = T> + Copy> RoundedRectangle<T>
impl<T: Sub<Output = T> + Copy> RoundedRectangle<T>
Sourceimpl<T> RoundedRectangle<T>
impl<T> RoundedRectangle<T>
Sourceimpl<T: PartialEq> RoundedRectangle<T>
impl<T: PartialEq> RoundedRectangle<T>
Sourcepub fn is_zero_area(&self) -> bool
pub fn is_zero_area(&self) -> bool
Returns true if the rectangle containing this rounded rectangle has
zero area. (the radius is not taken into account)
Sourceimpl<T: PartialOrd> RoundedRectangle<T>
impl<T: PartialOrd> RoundedRectangle<T>
Sourcepub fn is_positive_area(&self) -> bool
pub fn is_positive_area(&self) -> bool
Returns true if the rectangle containing this rounded rectangle has
positive area. (the radius is not taken into account)
Sourceimpl<T: Copy> RoundedRectangle<T>
impl<T: Copy> RoundedRectangle<T>
Sourcepub fn with_offset(&self, offset: impl Into<Vector2<T>>) -> Self
pub fn with_offset(&self, offset: impl Into<Vector2<T>>) -> Self
Returns a new rounded rectangle, whose vertices are offset relative to the current rounded rectangle by the specified amount. This is equivalent to adding the specified vector to each vertex.
Sourceimpl<T: Copy> RoundedRectangle<T>
impl<T: Copy> RoundedRectangle<T>
Sourcepub fn with_negative_offset(&self, offset: impl Into<Vector2<T>>) -> Self
pub fn with_negative_offset(&self, offset: impl Into<Vector2<T>>) -> Self
Returns a new rounded rectangle, whose vertices are negatively offset relative to the current rectangle by the specified amount. This is equivalent to subtracting the specified vector to each vertex.
Sourceimpl<T: AsPrimitive<f32>> RoundedRectangle<T>
impl<T: AsPrimitive<f32>> RoundedRectangle<T>
Sourcepub fn into_f32(self) -> RoundedRectangle<f32>
pub fn into_f32(self) -> RoundedRectangle<f32>
Returns a new rounded rectangle where the coordinates and the radius
have been cast to f32 values, using the as operator.
Sourceimpl<T: AsPrimitive<f32> + Copy> RoundedRectangle<T>
impl<T: AsPrimitive<f32> + Copy> RoundedRectangle<T>
Sourcepub fn as_f32(&self) -> RoundedRectangle<f32>
pub fn as_f32(&self) -> RoundedRectangle<f32>
Returns a new rectangle where the coordinates have been cast to f32
values, using the as operator.